/*****************************************************************************
 * raw.c: raw input
 *****************************************************************************
 * Copyright (C) 2003-2012 x264 project
 *
 * Authors: Laurent Aimar <fenrir@via.ecp.fr>
 *          Loren Merritt <lorenm@u.washington.edu>
 *          Steven Walters <kemuri9@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111, USA.
 *
 * This program is also available under a commercial proprietary license.
 * For more information, contact us at licensing@x264.com.
 *****************************************************************************/

#include "input.h"
#include "../../MyCapture/MyCaptureLib.h"

#define FAIL_IF_ERROR( cond, ... ) FAIL_IF_ERR( cond, "stream", __VA_ARGS__ )

typedef struct
{
    int next_frame;
} stream_hnd_t;

static int open_file(char *psz_filename, hnd_t *p_handle, video_info_t *info, cli_input_opt_t *opt )
{
    stream_hnd_t *h = calloc( 1, sizeof(stream_hnd_t) );
    if( !h )
        return -1;
    if (myCaptureInit() != 0)
    {
        return -1;
    }
    info->csp = X264_CSP_YV16;

    h->next_frame = 0;
    info->width = 640;
    info->height = 480;
    //info->csp = X264_CSP_I422;

    info->thread_safe = 1;
    info->num_frames  = 100;
    info->vfr         = 0;
    *p_handle = h;
    return 0;
}

static int read_frame( cli_pic_t *pic, hnd_t handle, int i_frame )
{
    stream_hnd_t *h = handle;

    while( i_frame > h->next_frame )
    {
        if( myCaptureSkip() != 0)
        {
            return -1;
        }
        h->next_frame++;
    }
    if( myCaptureRead(pic->img.plane) != 0)
    {
        return -1;
    }
    h->next_frame = i_frame+1;
    return 0;
}

static int close_file( hnd_t handle )
{
    stream_hnd_t *h = handle;
    free( h );
    myCaptureClose();
    return 0;
}

const cli_input_t stream_input = { open_file, x264_cli_pic_alloc, read_frame, NULL, x264_cli_pic_clean, close_file };
